@@ -54,6 +54,7 @@ class MailFolder:
 class Saera:
 	def __init__(self):
 		self.mailfolders = []
+		self.ims = []
 		self.lines = [['What can I help you with?',False]]
 		try:
 			program = hildon.Program.get_instance()
@@ -102,6 +103,9 @@ class Saera:
 
 		self.init_gst()
 		self.init_mail()
+		
+		# Commented out because there is a bug in the sqlite line that I can't find.
+		#gobject.timeout_add(10000, self.check_texts)
 
 		self.current_message = None
 
@@ -250,6 +254,31 @@ class Saera:
 		# return False
 		gobject.timeout_add(45000, self.check_mail)
 
+	def check_texts(self):
+		self.pipeline.set_state(gst.STATE_PAUSED)
+		# smsp = os.popen('sqlite3 /home/user/.rtcom-eventlogger/el-vl.db "Select remote_uid, free_text, outgoing, is_read, \
+		# 				storage_time from Events where service_id=3 and event_type_id=11 and outgoing=0 and is_read=0 \
+		# 				order by storage_time desc ; Update Events set is_read = 1 where service_id=3 and event_type_id=11 and outgoing=0"')
+		smsp = os.popen('sqlite3 /home/user/.rtcom-eventlogger/el-vl.db "Select remote_uid, free_text from Events where \
+						service_id=3 and event_type_id=11 and outgoing=0 and is_read=0 \
+						order by storage_time desc ; Update Events set is_read = 1 where service_id=3 and event_type_id=11 and outgoing=0 and is_read=0"')
+		sms_texts = smsp.read()
+		smsp.close()
+		# imp = os.popen('sqlite3 /home/user/.rtcom-eventlogger/el-vl.db "Select remote_uid, free_text, outgoing, is_read, \
+		# 				storage_time from Events where service_id=3 and event_type_id=4 and outgoing=0 and is_read=0 \
+		# 				order by storage_time desc ; Update Events set is_read = 1 where service_id=3 and event_type_id=4 and outgoing=0"')
+		imp = os.popen('sqlite3 /home/user/.rtcom-eventlogger/el-vl.db "Select remote_uid, free_text from Events where service_id=3 and event_type_id=4 and outgoing=0 and is_read=0 \
+						order by storage_time desc ; Update Events set is_read = 1 where service_id=3 and event_type_id=4 and outgoing=0 and is_read=0"')
+		im_texts = imp.read()
+		imp.close()
+		smsp = sms_texts.split('\n')
+		imp = im_texts.split('\n')
+		imp = smsp+imp
+		imp = [j for j in [[i.split("|")[0],"|".join(i.split("|")[1:])] for i in imp] if j]
+		self.ims = imp
+		gobject.timeout_add(10000, self.check_texts)
+		self.read_ims()
+
 	def read_email(self):
 		self.pipeline.set_state(gst.STATE_PAUSED)
 		if self.current_message:
@@ -280,6 +309,29 @@ class Saera:
 					self.darea.queue_draw()
 					gobject.timeout_add(100, os.system, saera_processing.sent.espeak_cmdline+' "'+words+'"')
 
+	def read_ims(self):
+		try:
+			im = self.ims.pop()
+			words = "New message from "+im[0]+": "+im[1]
+			words1 = "New message from "+im[0].replace('1','one ').\
+											   replace('2','two ').\
+											   replace('3','three ').\
+											   replace('4','four ').\
+											   replace('5','five ').\
+											   replace('6','six ').\
+											   replace('7','seven ').\
+											   replace('8','eight ').\
+											   replace('9','nine ').\
+											   replace('0','zero ')+": "+im[1]
+			self.lines.append([words,False])
+			self.lines = self.lines[-20:]
+			self.darea.queue_draw()
+			os.system(saera_processing.sent.espeak_cmdline+' "'+words1+'"')
+			gobject.timeout_add(5000, self.read_ims)
+		except IndexError:
+			return
+
+
 	def open_settings(self):
 		def set_lang(widget, langs):
 			sel = [None]
@@ -390,8 +442,8 @@ class Saera:
 		print dir(asr)
 		
 		#Experimental. Custom model for higher accuracy.
-		asr.set_property('lm', 'model/3609.lm')
-		asr.set_property('dict', 'model/3609.dic')
+		asr.set_property('lm', 'model/0709.lm')
+		asr.set_property('dict', 'model/0709.dic')
 
 		bus = self.pipeline.get_bus()
 		bus.add_signal_watch()
